==> tikiwiki-10.2.txz: usr/local/www/tikiwiki-10.2/lib/test/core/Transition/AtLeastTest.php <==
<?php
// (c) Copyright 2002-2013 by authors of the Tiki Wiki CMS Groupware Project
//
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: AtLeastTest.php 44443 2013-01-05 20:30:09Z changi67 $

/**
 * @group unit
 *
 */

class Transition_AtLeastTest extends PHPUnit_Framework_TestCase
{
	function testOver()
	{
		$transition = new Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 2, array('C', 'D', 'E', 'F', 'G'));

		$this->assertEquals(array(), $transition->explain());
	}

	function testRightOn()
	{
		$transition = new Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 3, array('C', 'D', 'E', 'F', 'G'));

		$this->assertEquals(array(), $transition->explain());
	}

	function testUnder()
	{
		$transition = new Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 4, array('C', 'D', 'E', 'F', 'G'));

		$this->assertEquals(
			array(array('class' => 'missing', 'count' => 1, 'set' => array('E', 'G')),),
			$transition->explain()
		);
	}

	function testImpossibleCondition()
	{
		$transition = new Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 4, array('C', 'D', 'E'));

		$this->assertEquals(
			array(array('class' => 'invalid', 'count' => 4, 'set' => array('C', 'D', 'E')),),
			$transition->explain()
		);
	}
}

==> tikiwiki-15.0.txz: usr/local/www/tikiwiki-15.0/lib/test/core/Transition/AtLeastTest.php <==
<?php
// (c) Copyright 2002-2016 by authors of the Tiki Wiki CMS Groupware Project
//
// All Rights Reserved. See copyright.txt for details and a complete list of authors.
// Licensed under the GNU LESSER GENERAL PUBLIC LICENSE. See license.txt for details.
// $Id: AtLeastTest.php 57944 2016-03-17 19:26:53Z jyhem $

/**
 * @group unit
 *
 */

class Transition_AtLeastTest extends PHPUnit_Framework_TestCase
{
	function testOver()
	{
		$transition = new Tiki_Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 2, array('C', 'D', 'E', 'F', 'G'));

		$this->assertEquals(array(), $transition->explain());
	}

	function testRightOn()
	{
		$transition = new Tiki_Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 3, array('C', 'D', 'E', 'F', 'G'));

		$this->assertEquals(array(), $transition->explain());
	}

	function testUnder()
	{
		$transition = new Tiki_Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 4, array('C', 'D', 'E', 'F', 'G'));

		$this->assertEquals(
			array(array('class' => 'missing', 'count' => 1, 'set' => array('E', 'G')),),
			$transition->explain()
		);
	}

	function testImpossibleCondition()
	{
		$transition = new Tiki_Transition('A', 'B');
		$transition->setStates(array('A', 'C', 'D', 'F'));
		$transition->addGuard('atLeast', 4, array('C', 'D', 'E'));

		$this->assertEquals(
			array(array('class' => 'invalid', 'count' => 4, 'set' => array('C', 'D', 'E')),),
			$transition->explain()
		);
	}
}
